# Changelog

## 2.0.0 (2025-03-27)

Full Changelog: [v1.1.0...v2.0.0](https://github.com/hanzoai/python-sdk/compare/v1.1.0...v2.0.0)

### Features

* **api:** api update ([#14](https://github.com/hanzoai/python-sdk/issues/14)) ([bd5f39c](https://github.com/hanzoai/python-sdk/commit/bd5f39c1eb8f8fdf04443ee8b448184b80759785))

## 1.1.0 (2025-03-26)

Full Changelog: [v1.0.0...v1.1.0](https://github.com/hanzoai/python-sdk/compare/v1.0.0...v1.1.0)

### Features

* **api:** api update ([#12](https://github.com/hanzoai/python-sdk/issues/12)) ([d37d657](https://github.com/hanzoai/python-sdk/commit/d37d657eea2988c528bb1cb7560f6e0ab2f1e61e))
* **api:** update via SDK Studio ([#4](https://github.com/hanzoai/python-sdk/issues/4)) ([e5137ed](https://github.com/hanzoai/python-sdk/commit/e5137ed411811a52ff9b7cc0e44a678ef3f3065e))
* **api:** update via SDK Studio ([#6](https://github.com/hanzoai/python-sdk/issues/6)) ([8da866d](https://github.com/hanzoai/python-sdk/commit/8da866dea4cc031c8388be2e013f79f96f6f2950))


### Bug Fixes

* **ci:** ensure pip is always available ([#9](https://github.com/hanzoai/python-sdk/issues/9)) ([42dc32d](https://github.com/hanzoai/python-sdk/commit/42dc32d241c11794317fa4a89ee7e1a15a58855b))
* **ci:** remove publishing patch ([#10](https://github.com/hanzoai/python-sdk/issues/10)) ([339a613](https://github.com/hanzoai/python-sdk/commit/339a6135e50161ae8acacaf7d1d7381a6d77428d))


### Chores

* go live ([#1](https://github.com/hanzoai/python-sdk/issues/1)) ([c1f495e](https://github.com/hanzoai/python-sdk/commit/c1f495ea0e560ada8c76c571b42928bf8e1b5ee5))
* go live ([#11](https://github.com/hanzoai/python-sdk/issues/11)) ([7e1b48c](https://github.com/hanzoai/python-sdk/commit/7e1b48ce65cba77dd8fbd7e019d3913c492a87a6))
* **internal:** codegen related update ([#8](https://github.com/hanzoai/python-sdk/issues/8)) ([ebc4649](https://github.com/hanzoai/python-sdk/commit/ebc4649173ca01aeb26903c6fe32adad0be49491))
* update SDK settings ([#3](https://github.com/hanzoai/python-sdk/issues/3)) ([beb5358](https://github.com/hanzoai/python-sdk/commit/beb53583fcdb15983f09a73be166dbbca30fb93f))

## 0.1.0-alpha.1 (2025-03-15)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/hanzoai/python-sdk/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([#4](https://github.com/hanzoai/python-sdk/issues/4)) ([e5137ed](https://github.com/hanzoai/python-sdk/commit/e5137ed411811a52ff9b7cc0e44a678ef3f3065e))


### Chores

* go live ([#1](https://github.com/hanzoai/python-sdk/issues/1)) ([c1f495e](https://github.com/hanzoai/python-sdk/commit/c1f495ea0e560ada8c76c571b42928bf8e1b5ee5))
* update SDK settings ([#3](https://github.com/hanzoai/python-sdk/issues/3)) ([beb5358](https://github.com/hanzoai/python-sdk/commit/beb53583fcdb15983f09a73be166dbbca30fb93f))
